@@ -17,6 +17,6 @@ extern int _XS_is_frobenius_underwood_pseudoprime(UV n);
 extern int _XS_is_almost_extra_strong_lucas_pseudoprime(UV n, UV increment);
 
 extern int _XS_BPSW(UV const n);
-extern int _XS_is_prob_prime(UV n);
+extern int is_prob_prime(UV n);
 
 #endif
